Module types

Structs

CommandOutput
Contains the raw output (stdout/stderr), exit code, timing information, etc.
CommandResult
Wraps the command that was run plus its resulting output.

Enums

OutputError
Errors that can occur when processing or parsing command output
OutputFormat
Different ways to interpret command output
ProcessedOutput
Encapsulates possible result types after formatting stdout