Structs
- Command
Output - Contains the raw output (stdout/stderr), exit code, timing information, etc.
- Command
Result - Wraps the command that was run plus its resulting output.
Enums
- Output
Error - Errors that can occur when processing or parsing command output
- Output
Format - Different ways to interpret command output
- Processed
Output - Encapsulates possible result types after formatting stdout